@@ -33,13 +33,14 @@
 #include "gkr-pk-util.h"
 
 #include "common/gkr-crypto.h"
+#include "common/gkr-id.h"
 #include "common/gkr-location.h"
-#include "common/gkr-unique.h"
 
 #include "pkcs11/pkcs11.h"
 #include "pkcs11/pkcs11g.h"
 
 #include "pkix/gkr-pkix-der.h"
+#include "pkix/gkr-pkix-serialize.h"
 
 #include <glib.h>
 #include <glib-object.h>
@@ -105,7 +106,7 @@ get_public_key (GkrPkPrivkey *key, gboolean force)
 {
 	gcry_sexp_t s_key = NULL;
 	GkrPkObject *obj;
-	GkrParseResult res;
+	GkrPkixResult res;
 	guchar *data;
 	gsize n_data;
 
@@ -118,7 +119,7 @@ get_public_key (GkrPkPrivkey *key, gboolean force)
 	data = gkr_pk_index_get_binary (obj, "public-key", &n_data);
 	if (data) {
 		res = gkr_pkix_der_read_public_key (data, n_data, &s_key);
-		if (res == GKR_PARSE_SUCCESS) {
+		if (res == GKR_PKIX_SUCCESS) {
 			key->priv->pubkey = gkr_pk_pubkey_instance (obj->manager, 
 			                                            obj->location, s_key);
 			goto done;
@@ -307,7 +308,7 @@ static CK_RV
 attribute_from_certificate (GkrPkPrivkey *key, CK_ATTRIBUTE_PTR attr)
 {
 	GkrPkObject *crt, *obj;
-	gkrconstunique keyid;
+	gkrconstid keyid;
 	
 	keyid = gkr_pk_privkey_get_keyid (key);
 	if (!keyid)
@@ -390,7 +391,7 @@ static CK_RV
 gkr_pk_privkey_get_attribute (GkrPkObject* obj, CK_ATTRIBUTE_PTR attr)
 {
 	GkrPkPrivkey *key = GKR_PK_PRIVKEY (obj);
-	gkrconstunique keyid;
+	gkrconstid keyid;
 	GQuark *quarks;
 	guchar *value;
 	gsize len;
@@ -449,7 +450,7 @@ gkr_pk_privkey_get_attribute (GkrPkObject* obj, CK_ATTRIBUTE_PTR attr)
 		keyid = gkr_pk_privkey_get_keyid (key);
 		if (!keyid) 
 			return CKR_GENERAL_ERROR;
-		value = (CK_VOID_PTR)gkr_unique_get_raw (keyid, &len);
+		value = (CK_VOID_PTR)gkr_id_get_raw (keyid, &len);
 		gkr_pk_attribute_set_data (attr, value, len);
 		return CKR_OK;
 
@@ -503,6 +504,20 @@ gkr_pk_privkey_get_attribute (GkrPkObject* obj, CK_ATTRIBUTE_PTR attr)
 	return GKR_PK_OBJECT_CLASS (gkr_pk_privkey_parent_class)->get_attribute (obj, attr);
 }
 
+static guchar*
+gkr_pk_privkey_serialize (GkrPkObject *obj, const gchar *password, gsize *n_data)
+{
+	GkrPkPrivkey *key = GKR_PK_PRIVKEY (obj);
+	
+	if (!load_private_key (key))
+		return NULL;
+		
+	g_return_val_if_fail (key->priv->s_key, NULL);
+	
+	/* Write it out */
+	return gkr_pkix_serialize_private_key_pkcs8 (key->priv->s_key, password, n_data);
+}
+
 static void
 gkr_pk_privkey_dispose (GObject *obj)
 {
@@ -542,6 +557,7 @@ gkr_pk_privkey_class_init (GkrPkPrivkeyClass *klass)
 	
 	parent_class = GKR_PK_OBJECT_CLASS (klass);
 	parent_class->get_attribute = gkr_pk_privkey_get_attribute;
+	parent_class->serialize = gkr_pk_privkey_serialize;
 	
 	gobject_class = (GObjectClass*)klass;
 	gobject_class->get_property = gkr_pk_privkey_get_property;
@@ -561,20 +577,20 @@ gkr_pk_privkey_new (GkrPkObjectManager *mgr, GQuark location, gcry_sexp_t s_key)
 {
 	GkrPkObject *key;
 	guchar hash[20];
-	gkrunique unique; 
+	gkrid digest; 
 	
 	g_return_val_if_fail (s_key != NULL, NULL);
 	
 	if (!gcry_pk_get_keygrip (s_key, hash))
 		g_return_val_if_reached (NULL);
 	
-	/* We need to create a unique for this key */
-	unique = gkr_unique_new_digestv ((const guchar*)"private-key", 11, hash, 20, NULL);
+	/* We need to create a digest for this key */
+	digest = gkr_id_new_digestv ((const guchar*)"private-key", 11, hash, 20, NULL);
 	
 	key = g_object_new (GKR_TYPE_PK_PRIVKEY, "manager", mgr, "location", location, 
-	                    "gcrypt-sexp", s_key, "unique", unique, NULL);
+	                    "gcrypt-sexp", s_key, "digest", digest, NULL);
 	                    
-	gkr_unique_free (unique);
+	gkr_id_free (digest);
 	
 	return key;
 }
@@ -617,7 +633,7 @@ gkr_pk_privkey_create (GkrPkObjectManager* manager, GArray* array,
 	return CKR_OK;
 }
 
-gkrconstunique
+gkrconstid
 gkr_pk_privkey_get_keyid (GkrPkPrivkey *key)
 {
 	GkrPkPubkey *pub;
@@ -626,6 +642,9 @@ gkr_pk_privkey_get_keyid (GkrPkPrivkey *key)
 	
 	/* Access via public key */
 	pub = get_public_key (key, TRUE);
+	if(!pub)
+		return NULL;
+	
 	return gkr_pk_pubkey_get_keyid (pub);
 }
 
